--
-- RB460
-- Specialization for New Holland BB 980 from Strawmod
--
-- @author  	Benjamin Biot (J&B Modding)
-- @version 	v1.0
-- @date  		21/11/10
--

RB460 = {};

RB460.UNLOADING_CLOSED = 1;
RB460.UNLOADING_OPENING = 2;
RB460.UNLOADING_OPEN = 3;
RB460.UNLOADING_CLOSING = 4;

function RB460.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Fillable, specializations);
end;

function RB460:load(xmlFile)
	self.getIsAreaActive = Utils.overwrittenFunction(self.getIsAreaActive, RB460.getIsAreaActive);		
	self.setPickup= SpecializationUtil.callSpecializationsFunction("setPickup");
		
	-- Animations --
	self.PickupAnimation = getXMLString(xmlFile, "vehicle.Pickup#animationName");
	self.Pickup = false;
	
	-- Animated objects --
	self.numRotParts = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.RotParts#count"), 0);	
    self.RotParts = {};
    for i=1, self.numRotParts do
        local RotPartsnamei = string.format("vehicle.RotParts.RotPart" .. "%d", i);
        self.RotParts[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, RotPartsnamei .. "#index"));
    end;
    local path = Utils.getFilename("Balecounter_hud.dds", self.baseDirectory);
    self.balecounterHud = Overlay:new("counterOverlay", path, 0.8143, 0.8315, 0.176, 0.06638);
    self.baleCount = 0;
    self.lastBaleCount = 0;
end;

function RB460:delete()
	if self.balecounterHud ~= nil then
		self.balecounterHud:delete();
	end;
end;

function RB460:readStream(streamId, connection)
    self:setPickup(streamReadBool(streamId), true);
    self.baleCount = streamReadInt32(streamId);
end;

function RB460:writeStream(streamId, connection)
    streamWriteBool(streamId, self.Pickup);
    streamWriteInt32(streamId, self.baleCount);
end;

function RB460:readUpdateStream(streamId, timestamp, connection)
end;

function RB460:writeUpdateStream(streamId, connection, dirtyMask)
end;

function RB460:mouseEvent(posX, posY, isDown, isUp, button)
end;

function RB460:keyEvent(unicode, sym, modifier, isDown)
end;

function RB460:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'baleCount="'.. tostring(self.baleCount) ..'"';
	return attributes, nil;
end;

function RB460:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		self.baleCount = Utils.getNoNil(getXMLInt(xmlFile, key.."#baleCount"), 0);
	end;
end;

function RB460:update(dt)		
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.LOWER_IMPLEMENT) then
			self:setPickup(not self.Pickup);
		end;
		if InputBinding.hasEvent(InputBinding.DEUTZ_RB460_RESET) then
			self.baleCount = 0;
		end;
    end;
end;

function RB460:updateTick(dt)	
	if self:getIsActive() then	
		-- Animating the pickup elements --
		if self.isTurnedOn and not self.Transport then
			for i=1, 1 do
				rotate(self.RotParts[i], -0.01 * dt, 0, 0);
			end;
		end;			
	end;
	if table.getn(self.bales) > self.lastBaleCount then
		self.baleCount = self.baleCount + 1;
		self.lastBaleCount = self.lastBaleCount + 1;
	elseif table.getn(self.bales) < self.lastBaleCount then
		self.lastBaleCount = self.lastBaleCount - 1;
	end;	
end;

function RB460:draw()
	if self.PickupDown then
		g_currentMission:addHelpButtonText(string.format(g_i18n:getText("PICKUP_LIFT"), self.typeDesc), InputBinding.LOWER_IMPLEMENT);
	else
		g_currentMission:addHelpButtonText(string.format(g_i18n:getText("PICKUP_LOWER"), self.typeDesc), InputBinding.LOWER_IMPLEMENT);
	end;
	g_currentMission:addHelpButtonText(g_i18n:getText("DeutzRB460_1"), InputBinding.KUHN_LSB_1270_RESET);
	self.balecounterHud:render();
	setTextAlignment(RenderText.ALIGN_RIGHT);
	setTextBold(true);	
	setTextColor(1, 1, 1, 1);
	renderText(0.9653, 0.849, 0.032, tostring(self.baleCount));	
end;

function RB460:setPickup(isPickupState,noEventSend)
	SetPickupEvent.sendEvent(self, isPickupState, noEventSend);
	-- Play pickup animation --
	self.PickupDown = isPickupState;
	if self.PickupDown then
		if self.PickupAnimation ~= nil and self.playAnimation ~= nil then
			self:playAnimation(self.PickupAnimation, -1, nil, true);
			self.Pickup = true;
		end;
	else
		if self.PickupAnimation ~= nil and self.playAnimation ~= nil then
			self:playAnimation(self.PickupAnimation, 1, nil, true);
			self.Pickup = false;
		end;
	end;	
end;

function RB460:onDetach()
end;

function RB460:getIsAreaActive(superFunc, area)
    if superFunc ~= nil then
			return superFunc(self, area) and self.PickupDown;
    end;
	return self.PickupDown;	
end;